# Sorcha Add-ons


[![ci](https://github.com/dirac-institute/sorcha-addons/actions/workflows/smoke-test.yml/badge.svg)](https://github.com/dirac-institute/sorcha-addons/actions/workflows/smoke-test.yml)
[![pytest](https://github.com/dirac-institute/sorcha-addons/actions/workflows/testing-and-coverage.yml/badge.svg)](https://github.com/dirac-institute/sorcha-addons/actions/workflows/testing-and-coverage.yml)
[![Documentation Status](https://readthedocs.org/projects/sorcha-addons/badge/?version=latest)](https://sorcha-addons.readthedocs.io/en/latest/?badge=latest)
[![astropy](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org/) 
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/sorcha-addons/badges/version.svg)](https://anaconda.org/conda-forge/sorcha-addons)
[![PyPI - Version](https://img.shields.io/pypi/v/sorcha-addons)](https://pypi.python.org/pypi/sorcha-addons)
[![Template](https://img.shields.io/badge/Template-LINCC%20Frameworks%20Python%20Project%20Template-brightgreen)](https://lincc-ppt.readthedocs.io/en/latest/)

This is a repository for community generated light curve and cometary activity
formulations for the [Sorcha](https://github.com/dirac-institute/sorcha) Solar
System survey simulator software package. Further details  can be found in the
[Sorcha documentation](https://sorcha.readthedocs.io). 

Details about how to install the Sorcha Add-ons package can be found in this package's specific documentation: https://sorcha-addons.readthedocs.io


##Sorcha Team
This effort is a collaboration between Queen's University Belfast, the University of Washington's DiRAC Institute, 
the University of Illinois at Urbana-Champaign, the Center for Astrophysics | Harvard & Smithsonian, and LINCC Frameworks (through the LINCC Frameworks Incubator Program). This project is supported in part by the generosity of Eric and Wendy Schmidt by recommendation of the Schmidt Futures program.


